@@ -4,7 +4,7 @@ macro_rules! call {
     (fn($($argument_type:ty),*) -> $result_type:ty, $closure:expr, $($argument:expr),* $(,)?) => {
         async {
             use core::{intrinsics::transmute, task::Poll};
-            use futures::future::poll_fn;
+            use $crate::future::__private::poll_fn;
             use $crate::{cps, Arc, Closure};
 
             const INITIAL_STACK_CAPACITY: usize = 64;
@@ -56,6 +56,10 @@ macro_rules! call {
     };
 }
 
+pub mod __private {
+    pub use futures::future::poll_fn;
+}
+
 #[cfg(test)]
 mod tests {
     use crate::{
